<?
/*	Photon
	lib-setuptest.php

	Set Up Tests
	included by panel.php
	
	(c) 2005 Red Quant Corporation
	Licensed under the Open Software License version 2.1 
	See file LICENSE in the root folder of this distribution
	
*/

include_once("globals.php");   // separated for scripts that don't need full lib.php

function setuptest()
{
	echo("<div class=sheet>");
	echo("<h2>Setup Test</h2>");
	echo("\n\n<table>\n");

	$ok = true;

	// User authentication
	// *******************
	// REMOTE_USER present, PHP_AUTH_PW present
	
	$proot = dirname($_SERVER['SCRIPT_FILENAME']);
	$ok = $ok && sutcheck("User Authentication", 
						isset($_SERVER['REMOTE_USER']),
						"ok", "failed",
			PROGRAM . " uses Apache/IIS authentication. PHP must be installed as module, not as cgi, and safe_mode must be disabled. This must be done with web server configuration/compilation and PHP setup, if it is not already set. If you have this, set up the directory protection as follows. You must have shell access, e.g. at the console or with ssh for this.<br>
			<br>
			The following is for Apache, if you know how to do it for IIS, please let me know at b5.iis@aimail.de<br>
			<br>
			<b>Enable basic user authentication for the Apache web server:</b><br>
			Use htpasswd to create user entries and passwords<br>
			You need to be at the console or log in with ssh or telnet to your server to do this.<br>
			Type htpasswd and hit return to see if the program is in the path.<br>
			If the system doesn't know the command, find it with<br>
			<pre>find / -name htpasswd</pre><br>
			and use the whole path to it (e.g. /usr/local/apache/bin/htpasswd) instead of only 'htpasswd' below (don't replace '.htpasswd', with a dot).<br>
			<br>
			Create .htpasswd in $proot:<br>
			<pre>htpasswd -c $proot/.htpasswd admin</pre><br>
			Make up and type in a password when prompted. You will need this to continue setup.<br>
			This created a new .htpasswd file with the first user 'admin', to add users execute:<br>
			htpasswd $proot/.htpasswd &lt;another-user-name><br>
			<br>
			Create .htaccess in $proot with this contents:<br>
			<br><pre>
AuthType Basic
AuthName \"Photon Traffic Stats\"
AuthUserFile $proot/.htpasswd 
require valid-user
			</pre><br>
			E.g. copy the above and use 'pico .htaccess' at the command line and paste these exact lines. Then use Ctrl-O to write it.
			<br><br>
			When you click 'test again', you should be asked for a log in.<br>
			When you get the path to .htpasswd wrong you won't be able to re-enter this page. Delete .htaccess then and try again.<br>
	");

	$ok = $ok && sutcheck("User password available", 
						(isset($_SERVER['PHP_AUTH_PW']) &&
						 $_SERVER['PHP_AUTH_PW']),
						"yes", "no",
						PROGRAM . " cannot run when the user password is not available to the system. PHP must be set up so that \$PHP_AUTH_PW is set. This is not possible when safe_mode is enabled or PHP is running as CGI. The HTTP Authentication hooks in PHP are only available when it is running as an Apache module and is hence not available in the CGI version. The PHP_AUTH variables will not be set if external authentication is enabled for that particular page and safe mode is enabled. See http://php.net/manual/en/features.http-auth.php for details.");
/*
	// Ini Files
	// *******************
	// Server, Client
	
	$ok = $ok && sutcheck("Serverwide ini file", 
						file_exists(serverinifilename()),
						"present", "missing",
						"Create file '" . serverinifilename() . "' from server.template.ini.<br>The serverwide ini file contains settings that are valid for all clients, users and operators sharing this server.");


	

	$ok = $ok && sutcheck("Client ini file", 
						file_exists(clientinifilename()),
						"present", "missing",
						"Create file '" . clientinifilename($client) . "' from client.template.ini.<br>
The client ini file lists users and their access rights, and chart presets.");
*/

	// Cache & Log dirs
	// *******************
	// existance, writability
	
	$ok = $ok && sutwriteabledir("cache", CACHEDIR, $ok);
	$ok = $ok && sutwriteabledir("logs", LOGDIR, $ok);
	

	// Test PHP/SWF Charts
	// *******************
	// Existence, access of charts.php, version
	


	$ok = $ok && sutcheck("PHP/SWF Charts package", 
						file_exists(PHPSWFCHARTS_MAINDIR),
						"installed", "missing",
						"Download free shareware PHP/SWF Charts version ".PHPSWFCHARTS_VERSION." from <a href='http://www.maani.us/charts/' target=_blank>http://www.maani.us/charts/</a> or <a href ='http://authinc.com/phpswfcharts/charts-".PHPSWFCHARTS_VERSION.".tgz' target=_blank>http://authinc.com/phpswfcharts/charts-".PHPSWFCHARTS_VERSION.".tgz</a>. Must be version ".PHPSWFCHARTS_VERSION."<br><br>Unpack within $proot/phpswfcharts, so that file charts.php is found in ".PHPSWFCHARTS_MAINDIR."/<br><br>Note: the package unpacks itself into the current directory, so cd into ".PHPSWFCHARTS_MAINDIR. " first.");

	$ok = $ok && sutcheck("PHP/SWF Charts installation", 
						file_exists(PHPSWFCHARTS_MAINFILE),
						"found", "misplaced",
						"Install PHP/SWF Charts so that charts.php is found as " . PHPSWFCHARTS_MAINFILE . ".");

	if($ok) $test = file(PHPSWFCHARTS_MAINFILE);

	$ok = $ok && sutcheck("PHP/SWF Charts version", 
						strstr($test[1], PHPSWFCHARTS_VERSION) !== false,
						PHPSWFCHARTS_VERSION, "wrong version",
						"PHP/SWF Charts must be version ".PHPSWFCHARTS_VERSION.". Download from http://authinc.com/phpswfcharts/".PHPSWFCHARTS_VERSION." if not available from http://www.maani.us/charts/.");

	echo("</table>\n\n");
	
	
	
	
	
	if($ok)
	{
		echo("<p>All tests passed ok.</p>");
		echo("<p>To run setup test again at a later time use menu entry <b>support</b>.</p>");
		
		// Flag: not *automatically* run self test again now.
		setswitch(SELFTEST_SWITCH_FILE);
		// Flag: Test passed now.
		setswitch(SELFTEST_OK_FLAG_FILE);
		// Flag: Test did pass once.
		setswitch(SETUP_COMPLETED_ONCE_FLAG_FILE);

		button("add client", "", "document.location.href = 'addclient.php'");

		button("test definitions", "", "document.location.href = 'data.php?showgrid=please'");

		?>
		<script>parent.parent.menuframe.location.reload();</script>
		<?

		phone(1, "Set Up Test: success.");

	}
	else
	{
		unsetswitch(SELFTEST_OK_FLAG_FILE);

		echo("<p></p>");
		button("test again", "", "document.location.reload()");
	}
	
	echo("</div>");
}

function sutwriteabledir($name, $dir, $ok)
// Set up check: test for existance of a dir and write testfile to it.
{
	$uname = ucwords($name);
	$ok = $ok && sutcheck("$uname directory '$dir'", is_dir($dir), "exists", "missing",
		"Create writable $name directory, named '<b>" . $dir . "</b>', relative to photon root (where index.php resides).");
	
	if($ok)
	{
		$fp = @fopen("$dir/testfile", "w");
		$ok = $ok && sutcheck("$uname writable", $fp, "ok", "failed",
			"Set $name directory '<b>".$dir."</b>' writeable.");
		
		if($fp) fwrite($fp, date("Y m d H m s"));
		if($fp) fclose($fp);
	}
	
	return $ok;
}

function sutcheck($prompt, $test, $oktext, $failtext, $hint)
// Set up check: assertion and echo of error/ok, hints.
{

	echo("<tr><td width=20%><p><b>$prompt</b></p></td>");
	if($test)
	{
		echo("<td><p class=ok>$oktext</p></td></tr>");	
	}
	else
	{
		echo("<td><p class=fail>$failtext</p></td></tr>\n");	
		echo("<tr><td colspan=2>"
			 ."<hr><h3>Set Up Instruction</h3>"
			 ."<p class=hint>$hint</p></td></tr>\n");	

		phone(1, "Set Up Test: failed on $failtext.");
	}

	return $test;
}

function setswitch($name)
// Write a file which's existence serves as a flag.
{
		$fp = fopen($name, "w");
		fwrite($fp, date("Y m d H:i:s"));
		fclose($fp);

}

function unsetswitch($name)
// Delete a file which's existence serves as a flag.
{
	@unlink($name);
}